==> information-system-model-3.0.0-20200211.143458-5-sources.jar: org/gcube/informationsystem/types/reference/relations/RelationType.java <==
package org.gcube.informationsystem.types.reference.relations;

import java.util.Set;

import org.gcube.informationsystem.base.reference.relations.RelationElement;
import org.gcube.informationsystem.types.annotations.ISProperty;
import org.gcube.informationsystem.types.impl.relations.RelationTypeImpl;
import org.gcube.informationsystem.types.reference.Type;
import org.gcube.informationsystem.types.reference.entities.EntityType;
import org.gcube.informationsystem.types.reference.properties.PropertyDefinition;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonDeserialize(as = RelationTypeImpl.class)
public interface RelationType<S extends EntityType, T extends EntityType>
		extends Type, RelationElement<S,T> {
	
	public static final String NAME = "RelationType"; // RelationType.class.getSimpleName();
	
	/* TypeDefinition is just a Java useful class. The type is not created in the IS. Hence the fields must be redefined */
	
	@Override
	@ISProperty(name = Type.NAME_PROPERTY, readonly = true, mandatory = true, nullable = false)
	public String getName();
	
	@Override
	@ISProperty(name = Type.DESCRIPTION_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public String getDescription();
	
	@Override
	@ISProperty(name = Type.ABSTRACT_PROPERTY, readonly = true, mandatory = true, nullable = false)
	public boolean isAbstract();
	
	@Override
	@ISProperty(name = Type.TYPE_SUPERCLASSES_PROPERTY, readonly = true, mandatory = true, nullable = false)
	public Set<String> getSuperClasses();
	
	@Override
	@ISProperty(name = Type.PROPERTIES_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Set<PropertyDefinition> getProperties();
	
	@Override
	public S getSource();
	
	@Override
	public T getTarget();
	
	/* TypeDefinition is just a Java useful class. The type is not created in the IS. Hence the fields must be redefined */
	/*@JsonGetter(value=SOURCE_PROPERTY)
	public String getSourceType();
	
	@JsonGetter(value=TARGET_PROPERTY)
	public String getTargetType();*/
	
}

==> information-system-model-4.0.0-20201014.163354-25-sources.jar: org/gcube/informationsystem/types/reference/relations/RelationType.java <==
package org.gcube.informationsystem.types.reference.relations;

import java.util.Set;

import org.gcube.com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import org.gcube.com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import org.gcube.informationsystem.base.reference.relations.RelationElement;
import org.gcube.informationsystem.types.annotations.ISProperty;
import org.gcube.informationsystem.types.impl.relations.RelationTypeImpl;
import org.gcube.informationsystem.types.reference.Type;
import org.gcube.informationsystem.types.reference.entities.EntityType;
import org.gcube.informationsystem.types.reference.properties.PropertyDefinition;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonDeserialize(as = RelationTypeImpl.class)
public interface RelationType<S extends EntityType, T extends EntityType>
		extends Type, RelationElement<S,T> {
	
	public static final String NAME = "RelationType"; // RelationType.class.getSimpleName();
	
	/* TypeDefinition is just a Java useful class. The type is not created in the IS. Hence the fields must be redefined */
	
	@Override
	@ISProperty(name = Type.NAME_PROPERTY, readonly = true, mandatory = true, nullable = false)
	public String getName();
	
	@Override
	@ISProperty(name = Type.DESCRIPTION_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public String getDescription();
	
	@Override
	@ISProperty(name = Type.ABSTRACT_PROPERTY, readonly = true, mandatory = true, nullable = false)
	public boolean isAbstract();
	
	@Override
	@ISProperty(name = Type.TYPE_SUPERCLASSES_PROPERTY, readonly = true, mandatory = true, nullable = false)
	public Set<String> getSuperClasses();
	
	@Override
	@ISProperty(name = Type.PROPERTIES_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Set<PropertyDefinition> getProperties();
	
	@Override
	public S getSource();
	
	@Override
	public T getTarget();
	
	/* TypeDefinition is just a Java useful class. The type is not created in the IS. Hence the fields must be redefined */
	/*@JsonGetter(value=SOURCE_PROPERTY)
	public String getSourceType();
	
	@JsonGetter(value=TARGET_PROPERTY)
	public String getTargetType();*/
	
}
